@@ -45,7 +45,7 @@ rp.normal <- function(y, ylab = deparse(substitute(y)),
                         mean = runif(1, 0.9 * min(y) + 0.1 * max(y), 0.7 * min(y) + 0.3 * max(y)),
                         stan = runif(1, 0.8 * sd(y), 1.4 * sd(y)),
                         curve.showing = FALSE, fitted.showing = FALSE)
-   if (panel.plot & !require(tkrplot)) {
+   if (panel.plot & !requireNamespace("tkrplot", quietly = TRUE)) {
       warning("the tkrplot package is not available so panel.plot has been set to FALSE.")
       panel.plot <- FALSE
       }
